import React from 'react';
import { FlatList, View, Text as FText, TouchableOpacity as FTouchableOpacity } from 'react-native';
import Feather from 'react-native-vector-icons/Feather';
import MessageCard from '../messageCard';
import Styles from './Styles';
import PropTypes from 'prop-types';
import { Data } from './data';

const MessageList = _ref => {
  let {
    data,
    onViewAll,
    onPress,
    showViewAllButton
  } = _ref;

  const ViewAllButton = () => {
    return /*#__PURE__*/React.createElement(FTouchableOpacity, {
      style: Styles.viewAllButtonContainer,
      onPress: onViewAll
    }, /*#__PURE__*/React.createElement(FText, {
      style: Styles.viewAllText
    }, "View all"), /*#__PURE__*/React.createElement(View, {
      style: Styles.arrow
    }, /*#__PURE__*/React.createElement(Feather, {
      name: "arrow-right",
      size: 16,
      color: 'blue'
    }), /*#__PURE__*/React.createElement(View, {
      style: Styles.blueBackground
    })));
  };

  return /*#__PURE__*/React.createElement(FlatList, {
    data: data,
    renderItem: _ref2 => {
      let {
        item,
        index
      } = _ref2;
      return /*#__PURE__*/React.createElement(MessageCard, {
        isRead: item.read,
        title: item.title,
        tagsStrippedBody: item.tagsStrippedBody,
        dateTime: item.date,
        onPress: () => onPress(item, index)
      });
    },
    keyExtractor: item => item.id,
    ItemSeparatorComponent: () => /*#__PURE__*/React.createElement(View, {
      style: Styles.separator
    }),
    horizontal: true,
    ListFooterComponent: () => showViewAllButton ? /*#__PURE__*/React.createElement(ViewAllButton, null) : null,
    ListHeaderComponent: () => /*#__PURE__*/React.createElement(View, {
      style: Styles.separator
    }),
    showsHorizontalScrollIndicator: false,
    contentContainerStyle: Styles.listContentStyle
  });
};

export default MessageList;
MessageList.propTypes = {
  data: PropTypes.arrayOf(PropTypes.object),
  onViewAll: PropTypes.func,
  onPress: PropTypes.func,
  showViewAllButton: PropTypes.bool
};
MessageList.defaultProps = {
  data: Data,
  onViewAll: () => console.log('view all button pressed'),
  onPress: item => console.log('message pressed', item),
  showViewAllButton: true
};
//# sourceMappingURL=index.js.map